@@ -35,8 +35,9 @@ There are three types of models in this layer:
    defines a linear dynamical system which can be used to predict time series.
 """
 
+from datafold.dynfold.compose import TSCColumnTransformer
 from datafold.dynfold.dmap import DiffusionMaps, LocalRegressionSelection
-from datafold.dynfold.dmd import DMDBase, DMDEco, DMDFull
+from datafold.dynfold.dmd import DMDBase, DMDEco, DMDFull, PyDMDWrapper, gDMDFull
 from datafold.dynfold.outofsample import (
     GeometricHarmonicsInterpolator,
     LaplacianPyramidsInterpolator,
